@@ -1,19 +1,33 @@
-import imp
+import importlib.machinery
+import importlib.util
 import os
 import sys
 
 
+def load_source(modname, filename):
+    loader = importlib.machinery.SourceFileLoader(modname, filename)
+    spec = importlib.util.spec_from_file_location(
+        modname, filename, loader=loader
+    )
+    module = importlib.util.module_from_spec(spec)
+    # The module is always executed and not cached in sys.modules.
+    # Uncomment the following line to cache the module.
+    # sys.modules[module.__name__] = module
+    loader.exec_module(module)
+    return module
+
+
 # Add the extensions folder...
 sys.path.insert(0, os.path.abspath("./_extensions"))
 
-_version = imp.load_source("setup", "../src/klein/_version.py")
+_version = load_source("setup", "../src/klein/_version.py")
 
 extensions = []
 templates_path = ["_templates"]
 source_suffix = ".rst"
 master_doc = "index"
 project = "Klein"
-copyright = "2011-2021, Twisted Matrix Labs"
+copyright = "2011-2022, Twisted Matrix Labs"
 version = _version.__version__.base()
 release = version
 exclude_patterns = ["_build"]
@@ -55,4 +69,4 @@ texinfo_documents = [
 
 # API links extension, stolen from Twisted's Sphinx setup
 extensions.append("apilinks")
-apilinks_base_url = "https://twistedmatrix.com/documents/current/api/"
+apilinks_base_url = "https://docs.twisted.org/en/stable/api/"
